<?php
/**
 * @version		3.4.2 plugins/content/buttons/buttons.php
 * 
 * @package		Buttons
 * @subpackage	plg_content_buttons
 * @since		3.4
 *
 * @author		Helios Ciancio <info@eshiol.it>
 * @link		http://www.eshiol.it
 * @copyright	Copyright (C) 2015 Helios Ciancio. All Rights Reserved
 * @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL v3
 * Buttons is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */
 
// no direct access
defined('_JEXEC') or die('Restricted access.');

use Joomla\Registry\Registry;
require_once JPATH_SITE.'/components/com_buttons/helpers/buttons.php';

JModelLegacy::addIncludePath(JPATH_SITE.'/components/com_buttons/models', 'ButtonsModel');

class plgContentButtons extends JPlugin
{
	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 * @since  3.1
	 */
	protected $autoloadLanguage = true;
	
	/**
	 * Database object
	 *
	 * @var    JDatabaseDriver
	 * @since  3.3
	 */
	protected $db;	

	private $_params = null;
	private $_extension;
	
	/**
	 * Constructor
	 *
	 * @param  object  $subject  The object to observe
	 * @param  array   $config   An array that holds the plugin configuration
	 *
	 * @since       2.5
	 */
	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);
		$array = preg_split('#([A-Z][^A-Z]*)#', __CLASS__, null, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
		$this->_extension = $array[0].'_'.$array[1].'_'.$array[2];
		JLog::addLogger(array('logger' => 'messagequeue', 'extension' => $this->_extension), JLOG::ALL & ~JLOG::DEBUG, array($this->_extension));
		if (defined('JDEBUG') && JDEBUG)
			JLog::addLogger(array('text_file' => 'buttons.php', 'extension' => $this->_extension), JLog::ALL, array($this->_extension));		
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,$this->_extension));
		// Get the parameters.
		// TODO: merge $this->params and $config['params']
		if (isset($config['params']))
		{
			if ($config['params'] instanceof Registry)
			{
				$this->_params = $config['params'];
			}
			else
			{
				$this->_params = new Registry;
				$this->_params->loadString($config['params']);
			}
		}
	}

	/**
	 * Plugin that prepare content for report
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 * @param   mixed    &$row     An object with a "text" property
	 * @param   mixed    $params   Additional parameters. See {@see PlgContentContent()}.
	 * @param   integer  $page     Optional page number. Unused. Defaults to zero.
	 *
	 * @return  boolean	True on success.
	 */
	public function onContentPrepare($context, &$row, $params, $page = 0)
	{
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,$this->_extension));
		
		$allowed_contexts = array('com_content.article');
		if (!in_array($context, $allowed_contexts))
		{
			return true;
		}
	
		if (JFactory::getApplication()->input->getString('buttons') == 'report')
		{
			$row->text = $row->introtext;
			$row->params->set('access-edit',0);
		}
		return true;
	}
	
	
	/**
	 * Adds additional fields to the category editing form
	 *
	 * @param   JForm  $form  The form to be altered.
	 * @param   mixed  $data  The associated data for the form.
	 *
	 * @return  boolean
	 *
	 * @since   1.6
	 */
	public function onContentPrepareForm($form, $data)
	{
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,$this->_extension));
		
		$app = JFactory::getApplication();
		$formname = $form->getName();
		if ($formname == 'com_content.article')
		{
			JForm::addFormPath(__DIR__ . '/forms');
			//Show specific forms based on buttons
			$form->loadFile('article', false);
		}
		elseif ($app->isAdmin())
		{
			if ($formname == 'com_categories.categorycom_buttons')
			{
				JForm::addFormPath(__DIR__ . '/forms');	
				//Show specific forms based on categories
				$form->loadFile('toolbar', false);
			}
			elseif ($formname == 'com_categories.categorycom_content')
			{
				JForm::addFormPath(__DIR__ . '/forms');	
				//Show specific forms based on categories
				$form->loadFile('category', false);
			}
		}
		return true;
	}

	/**
	 * Displays the toolbar at the top of the article
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 * @param   mixed    &$row     An object with a "text" property
	 * @param   mixed    $params   Additional parameters. See {@see PlgContentContent()}.
	 * @param   integer  $page     Optional page number. Unused. Defaults to zero.
	 *
	 * @return  mixed  html string containing code for the buttons else boolean false
	 *
	 * @since   1.6
	 */
	public function onContentBeforeDisplay($context, &$row, &$params, $page=0)
	{
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,$this->_extension));

		$allowed_contexts = array('com_content.article','com_content.featured','com_content.category');
		if (!in_array($context, $allowed_contexts))
		{
			return true;
		}
		
		$html = '';
		if (JFactory::getApplication()->input->getString('buttons') != 'report')
		{
			$toolbars = ButtonsHelper::getToolbars($row, 'top');
			
			if (isset($row->asset_id))
			{
				$asset_id = $row->asset_id;
			}
			else
			{
				$article = JTable::getInstance('Content');
				$article->load($row->id);
				$asset_id = $article->asset_id;
			}
	
			JLog::add(new JLogEntry($row->title,JLOG::DEBUG,$this->_extension));
			JLog::add(new JLogEntry($this->params,JLOG::DEBUG,$this->_extension));
			$clearfix = '';
			foreach($toolbars as $catid)
			{
				JLog::add(new JLogEntry('catid: '.$catid,JLOG::DEBUG,$this->_extension));
			
				$toolbar = JTable::getInstance('Category');
				$toolbar->load($catid);
				$tparams = new Registry;
				$tparams->loadString($toolbar->params);
				JLog::add(new JLogEntry(print_r($tparams, true),JLOG::DEBUG,$this->_extension));
	
				if ($tparams->get('show_featured') != '')
				{
					$show_featured = $tparams->get('show_featured');
				}
				else
				{
					$show_featured = $this->params->get('show_featured');
				}
				JLog::add(new JLogEntry('show featured: '.$show_featured,JLOG::DEBUG,$this->_extension));
	
				if ($tparams->get('show_categoryblog') != '')
				{
					$show_categoryblog = $tparams->get('show_categoryblog');
				}
				else
				{
					$show_categoryblog = $this->params->get('show_categoryblog');
				}
				JLog::add(new JLogEntry('show category blog: '.$show_categoryblog,JLOG::DEBUG,$this->_extension));
	
				if (($context == 'com_content.article')
					|| (($context == 'com_content.featured') && $show_featured)
					|| (($context == 'com_content.category') && $show_categoryblog)
				) {
					$html .= '<span id="buttons-top-'.$asset_id.'-'.$catid.'">';
					$style = ($this->_params->get('report_style', 0) == 0 ? 'buttons' : 'text');
					$html .= ButtonsHelper::getToolbar($catid, $asset_id, JFactory::getUser()->id, true, $style);
					$html .= '</span>';
					$clearfix = '<div class="clearfix"></div>';
				}
			}
			$html .= $clearfix;
		}
		return $html;
	}

	
	/**
	 * Displays the toolbar at the bottom of the article
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 * @param   mixed    &$row     An object with a "text" property
	 * @param   mixed    $params   Additional parameters. See {@see PlgContentContent()}.
	 * @param   integer  $page     Optional page number. Unused. Defaults to zero.
	 *
	 * @return  mixed  html string containing code for the buttons else boolean false
	 *
	 * @since   1.6
	 */
	public function onContentAfterDisplay($context, &$row, &$params, $page=0)
	{
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,$this->_extension));
	
		$allowed_contexts = array('com_content.article','com_content.featured','com_content.category');
		if (!in_array($context, $allowed_contexts))
		{
			return true;
		}
		
		$html = '';
		if (JFactory::getApplication()->input->getString('buttons') != 'report')
		{
			$toolbars = ButtonsHelper::getToolbars($row, 'bottom');
		
			if (isset($row->asset_id))
			{
				$asset_id = $row->asset_id;
			}
			else
			{
				$article = JTable::getInstance('Content');
				$article->load($row->id);
				$asset_id = $article->asset_id;
			}
		
			JLog::add(new JLogEntry($row->title,JLOG::DEBUG,$this->_extension));
			JLog::add(new JLogEntry($this->params,JLOG::DEBUG,$this->_extension));
			$html = '';
			$clearfix = '';
			foreach($toolbars as $catid)
			{
				JLog::add(new JLogEntry('catid: '.$catid,JLOG::DEBUG,$this->_extension));
					
				$toolbar = JTable::getInstance('Category');
				$toolbar->load($catid);
				$tparams = new Registry;
				$tparams->loadString($toolbar->params);
				JLog::add(new JLogEntry(print_r($tparams, true),JLOG::DEBUG,$this->_extension));
		
				if ($tparams->get('show_featured') != '')
				{
					$show_featured = $tparams->get('show_featured');
				}
				else
				{
					$show_featured = $this->params->get('show_featured');
				}
				JLog::add(new JLogEntry('show featured: '.$show_featured,JLOG::DEBUG,$this->_extension));
		
				if ($tparams->get('show_categoryblog') != '')
				{
					$show_categoryblog = $tparams->get('show_categoryblog');
				}
				else
				{
					$show_categoryblog = $this->params->get('show_categoryblog');
				}
				JLog::add(new JLogEntry('show category blog: '.$show_categoryblog,JLOG::DEBUG,$this->_extension));
		
				if (($context == 'com_content.article')
						|| (($context == 'com_content.featured') && $show_featured)
						|| (($context == 'com_content.category') && $show_categoryblog)
						) {
							$html .= '<span id="buttons-bottom-'.$asset_id.'-'.$catid.'">';
							$style = ($this->_params->get('report_style', 0) == 0 ? 'buttons' : 'text');
							$html .= ButtonsHelper::getToolbar($catid, $asset_id, JFactory::getUser()->id, true, $style);
							$html .= '</span>';
							$clearfix = '<div class="clearfix"></div>';
						}
			}
			$html .= $clearfix;
		}
		else 
		{
			$authorisedViewLevels = JFactory::getUser()->getAuthorisedViewLevels();
			$report_access = false;
			$toolbars = ButtonsHelper::getToolbars($row);
			foreach($toolbars as $catid)
			{
				$toolbar = JTable::getInstance('Category');
				$toolbar->load($catid);
				$tparams = new Registry;
				$tparams->loadString($toolbar->params);
				$report_access = $report_access ||
				in_array($tparams->get('report_access', 3), $authorisedViewLevels);
			}
			if (!$report_access)
			{
				return;
			}
			if ($report_access)
			{
				if (isset($row->asset_id))
				{
					$asset_id = $row->asset_id;
				}
				else
				{
					$article = JTable::getInstance('Content');
					$article->load($row->id);
					$asset_id = $article->asset_id;
				}
		
				foreach($toolbars as $catid)
				{
//					$buttons = $this->_prepareReport($catid);
					$query = $this->db->getQuery(true)
						->select($this->db->qn(array('value','catid','modified','editor_user_id')))
						->from($this->db->qn('#__buttons_extras').' a')
						// Join over the users
						->select($this->db->qn('uc.name'))
						->join('LEFT', $this->db->qn('#__users').' AS '.$this->db->qn('uc').' ON '.$this->db->qn('uc.id').'='.$this->db->qn('a.editor_user_id'))
						// Filter by content
						->where($this->db->qn('asset_id').'='.$row->asset_id)
						// Filter by toolbar
						->where($this->db->qn('catid').'='.$catid)
						;
					JLog::add(new JLogEntry($query,JLOG::DEBUG,$this->_extension));
					$items = $this->db->setQuery($query)->loadObjectList();
					JLog::add(new JLogEntry(print_r($items, true),JLOG::DEBUG,$this->_extension));
					if ($items)
					{
						$style = (JFactory::getApplication()->input->getString('print') ? 'text' : 'buttons');						
						foreach($items as $item)
						{
							$item->toolbar = ButtonsHelper::getToolbar($catid, $row->asset_id, $item->editor_user_id, false, $style);
						}
						// Get the path for the layout file
						$path = JPluginHelper::getLayoutPath('content', 'buttons');
						// Render the toolbar
						ob_start();
						include $path;
						$html .= ob_get_clean();
					}
				}
			}
		}
		return $html;
	}
}